Protwarbar = LibStub("AceAddon-3.0"):NewAddon("Protwarbar", "AceEvent-3.0",  "AceConsole-3.0", "AceTimer-3.0")

local PWB = {}

PWB_ICON_COUNT = 14
PWB_BAR_COUNT = 6

function Protwarbar:OnInitialize()
	Protwarbar:SetDefaultMedia()

	PWB.db = LibStub('AceDB-3.0'):New('ProtwarbarDB', self:CreateDefaults(), true)
	PWB.db.RegisterCallback(self, "OnProfileChanged", "RefreshConfig")
	PWB.db.RegisterCallback(self, "OnProfileCopied", "RefreshConfig")
	PWB.db.RegisterCallback(self, "OnProfileReset", "RefreshConfig")

	AceConfig = LibStub("AceConfigDialog-3.0")
	LibStub("AceConfig-3.0"):RegisterOptionsTable("Protwarbar", self:CreateOptions())
	AceConfig:AddToBlizOptions("Protwarbar", "Protwarbar")

	Protwarbar:RegisterChatCommand('protwarbar', 'OnCommand')
end

function Protwarbar:OnCommand()
	InterfaceOptionsFrame_OpenToCategory("Protwarbar")
end

function Protwarbar:getPWB()
	return PWB
end

function Protwarbar:RefreshConfig()
	Protwarbar:UpdateStyling()
	Protwarbar:UpdateVisiblity()
end

function Protwarbar:OnEnable()
	local _, playerClass = UnitClass("player")
	PWB.class = nil
	PWB.spec = GetSpecialization()
	
	if playerClass == "WARRIOR" then
		PWB.class = 1
		PWB.Vengeance_name = GetSpellInfo(93098)
	elseif playerClass == "DRUID" then
		PWB.class = 2
		PWB.Vengeance_name = GetSpellInfo(84840)
	end

	if PWB.class ~= nil then
		Protwarbar:InitProtwarbar()
	else
		Protwarbar:Print("Protwarbar has been loaded but not enabled. Player class is not supported.")
	end

end

function Protwarbar:InitProtwarbar()
	PWB.talents = Protwarbar:GetActiveTalents()

	PWB.combat = false
	PWB.maxPower = UnitPowerMax("player")

	self:RegisterEvent("UNIT_POWER_FREQUENT")
	self:RegisterEvent("UNIT_MAXPOWER")
	self:RegisterEvent("UNIT_AURA")
	self:RegisterEvent("SPELL_UPDATE_COOLDOWN")
	self:RegisterEvent("PLAYER_REGEN_DISABLED")
	self:RegisterEvent("PLAYER_REGEN_ENABLED")
	self:RegisterEvent("ACTIVE_TALENT_GROUP_CHANGED")
	self:RegisterEvent("PLAYER_TALENT_UPDATE")
	
	Protwarbar:BuildGui()

	-- force update the bar every .1 seconds
	self:ScheduleRepeatingTimer("QuickTimer", 0.1)
end


function Protwarbar:OnDisable()
end

function Protwarbar:QuickTimer()
	Protwarbar:UpdateShieldBar()
end

-- start combat
function Protwarbar:PLAYER_REGEN_DISABLED()
	PWB.combat = true
	Protwarbar:UpdateVisiblity()
end

-- end combat
function Protwarbar:PLAYER_REGEN_ENABLED()
	PWB.combat = false
	Protwarbar:UpdateVisiblity()
end

function Protwarbar:UNIT_POWER_FREQUENT(eventName, unit, powerType)
	if (unit == "player") then
		Protwarbar:UpdateRageBar(UnitPower("player"))
		Protwarbar:UpdateInformation(UnitPower("player"))
	end
end

function Protwarbar:UNIT_AURA(eventName, unit)
	if (unit == "player") then
		Protwarbar:UpdateInformation(UnitPower("player"))
		Protwarbar:UpdateShieldBar()
	end
end

function Protwarbar:SPELL_UPDATE_COOLDOWN()
	Protwarbar:UpdateIcons()
end

function Protwarbar:UNIT_MAXPOWER()
	PWB.maxPower = UnitPowerMax("player")
	Protwarbar:UpdateStyling()
end

function Protwarbar:ACTIVE_TALENT_GROUP_CHANGED()
	PWB.spec = GetSpecialization()
	Protwarbar:UpdateVisiblity()
end

function Protwarbar:PLAYER_TALENT_UPDATE()
	PWB.talents = Protwarbar:GetActiveTalents()
	Protwarbar:UpdateVisiblity()
end

function Protwarbar:GetActiveTalents()
	local talents = {}
	local numTalents = GetNumTalents(3)
	for i = 1, numTalents do 
		local _, _, _, _, selected, _ = GetTalentInfo(i)
		talents[i] = selected
	end	
	return talents
end