local PWB = Protwarbar:getPWB()
local L = LibStub("AceLocale-3.0"):GetLocale("Protwarbar")

function Protwarbar:CreateOptions()
	local media = LibStub("LibSharedMedia-3.0")
	local textures = media:List("statusbar")
	local fonts = media:List("font")

	local options = {
		type = "group",
		name = "Prot War Bar",
		childGroups = "tab",
		args = {
			group1 = {
				name = L["General"],
				type = "group",
				order = 1,
				args = {
					enable = {
					  order = 1,
				      name = L["Enable"],
				      desc = L["Enables / disables the addon"],
					  type = "toggle",
				      set = function(info,val) PWB.db.profile.enabled = val Protwarbar:RefreshConfig() end,
				      get = function(info) return PWB.db.profile.enabled end
				    },
					locked = {
					  order = 2,
				      name = L["Lock frames"],
				      desc = L["When locked, you can not move the bar"],
					  type = "toggle",
				      set = function(info,val) PWB.db.profile.locked = val Protwarbar:RefreshConfig() end,
				      get = function(info) return PWB.db.profile.locked end
				    },
					desc_110 = {
						type = 'description',
						name = " ",
						order = 10,
					},
					hideooc = {
					  order = 11,
				      name = L["Hide out of combat"],
				      desc = L["Hide the frames when you are out of combat."],
					  type = "toggle",
				      set = function(info,val) PWB.db.profile.hideooc = val Protwarbar:RefreshConfig() end,
				      get = function(info) return PWB.db.profile.hideooc end
				    },
					protonly = {
					  order = 13,
				      name = L["Protection only"],
				      desc = L["Only display when using protection specialization"],
					  type = "toggle",
				      set = function(info,val) PWB.db.profile.showInProtOnly = val Protwarbar:RefreshConfig() end,
				      get = function(info) return PWB.db.profile.showInProtOnly end
				    },
			    },
		    },
		    group2 = {
				name = L["Rage bar"],
				type = "group",
				order = 2,
				args = {
					desc_pos = {
						type = 'header',
						name = L["Position"],
						order = 1,
					},
				    x = {
				        order = 3,
				    	name = "X",
				    	desc = "X",
				    	type = "range",
				    	min = 1,
				    	max = 2560,
				    	step = 1,
				      	set = function(info,val) PWB.db.profile.rageFrame.x = val Protwarbar:RefreshConfig() end,
				      	get = function(info) return PWB.db.profile.rageFrame.x end
					},
				    you = {
				        order = 3,
				    	name = "Y",
				    	desc = "Y",
				    	type = "range",
				    	min = 1,
				    	max = 2048,
				    	step = 1,
				      	set = function(info,val) PWB.db.profile.rageFrame.y = val Protwarbar:RefreshConfig() end,
				      	get = function(info) return PWB.db.profile.rageFrame.y end
					},					
					desc_6 = {
						type = 'description',
						name = " ",
						order = 6,
					},					
				    width = {
				        order = 7,
				    	name = L["Width"],
				    	desc = L["Width of rage bar"],
				    	type = "range",
				    	min = 5,
				    	max = 750,
				    	step = 1,
				      	set = function(info,val) PWB.db.profile.rageFrame.width = val Protwarbar:RefreshConfig() end,
				      	get = function(info) return PWB.db.profile.rageFrame.width end
					},
				    height = {
				        order = 8,
				    	name = L["Height"],
				    	desc = L["Height of bar"],
				    	type = "range",
				    	min = 5,
				    	max = 750,
				    	step = 1,
				      	set = function(info,val) PWB.db.profile.rageFrame.height = val Protwarbar:RefreshConfig() end,
				      	get = function(info) return PWB.db.profile.rageFrame.height end
					},
				    orient = {
				        order = 9,
				    	name = L["Orientation"],
				    	desc = L["Orientation"],
				    	type = "select",
						values = function()
							orientations = {
								["HORIZONTAL"] = "Horizontal",
								["VERTICAL"] = "Vertical",
							}
							return orientations
						end,
				      	set = function(info, v)
				      			PWB.db.profile.rageFrame.orientation = v
					      	 	Protwarbar:RefreshConfig() 
				      		end,
				      	get = function(info) return PWB.db.profile.rageFrame.orientation end
					},				
					desc_colour = {
						type = 'header',
						name = L["Bar colors"],
						order = 10,
					},					
				    color20 = {
				    	name = L["Color 0 - 19"],
				    	desc = L["Color 0 - 19"],
				    	type = "color",
				    	order = 15,
				    	hasAlpha = true,
				      	set = function(info, r, g, b, a) 
					      		PWB.db.profile.rageFrame.color20[1] = r;
					      		PWB.db.profile.rageFrame.color20[2] = g;
					      		PWB.db.profile.rageFrame.color20[3] = b;
					      		PWB.db.profile.rageFrame.color20[4] = a;
					      	 	Protwarbar:RefreshConfig() 
					      		end,
				      	get = function(info) return PWB.db.profile.rageFrame.color20[1], PWB.db.profile.rageFrame.color20[2],
				      								PWB.db.profile.rageFrame.color20[3], PWB.db.profile.rageFrame.color20[4] 
							end
					},
				    color60 = {
				    	name = L["Color 20 - 59"],
				    	desc = L["Color 20 - 59"],
				    	type = "color",
				    	order = 16,
				    	hasAlpha = true,
				      	set = function(info, r, g, b, a) 
					      		PWB.db.profile.rageFrame.color60[1] = r;
					      		PWB.db.profile.rageFrame.color60[2] = g;
					      		PWB.db.profile.rageFrame.color60[3] = b;
					      		PWB.db.profile.rageFrame.color60[4] = a;
					      	 	Protwarbar:RefreshConfig() 
					      		end,
				      	get = function(info) return PWB.db.profile.rageFrame.color60[1], PWB.db.profile.rageFrame.color60[2],
				      								PWB.db.profile.rageFrame.color60[3], PWB.db.profile.rageFrame.color60[4] 
							end
					},
					desc_colour2 = {
						type = 'description',
						name = " ",
						order = 20,
					},						
				    color100 = {
				        order = 27,
				    	name = L["Color 60 - 99"],
				    	desc = L["Color 60 - 99"],
				    	type = "color",
				    	hasAlpha = true,
				      	set = function(info, r, g, b, a) 
					      		PWB.db.profile.rageFrame.color100[1] = r;
					      		PWB.db.profile.rageFrame.color100[2] = g;
					      		PWB.db.profile.rageFrame.color100[3] = b;
					      		PWB.db.profile.rageFrame.color100[4] = a;
					      	 	Protwarbar:RefreshConfig() 
					      		end,
				      	get = function(info) return PWB.db.profile.rageFrame.color100[1], PWB.db.profile.rageFrame.color100[2],
				      								PWB.db.profile.rageFrame.color100[3], PWB.db.profile.rageFrame.color100[4] 
							end
					},
				    color120 = {
				        order = 28,
				    	name = L["Color 100 - 119"],
				    	desc = L["Color 100 - 119"],
				    	type = "color",
				    	hasAlpha = true,
				      	set = function(info, r, g, b, a) 
					      		PWB.db.profile.rageFrame.color120[1] = r;
					      		PWB.db.profile.rageFrame.color120[2] = g;
					      		PWB.db.profile.rageFrame.color120[3] = b;
					      		PWB.db.profile.rageFrame.color120[4] = a;
					      	 	Protwarbar:RefreshConfig() 
					      		end,
				      	get = function(info) return PWB.db.profile.rageFrame.color120[1], PWB.db.profile.rageFrame.color120[2],
				      								PWB.db.profile.rageFrame.color120[3], PWB.db.profile.rageFrame.color120[4] 
							end
					},					
					colorMax = {
				        order = 29,
				    	name = L["Color full bar"],
				    	desc = L["Color full bar"],
				    	type = "color",
				    	hasAlpha = true,
				      	set = function(info, r, g, b, a) 
					      		PWB.db.profile.rageFrame.colorMax[1] = r;
					      		PWB.db.profile.rageFrame.colorMax[2] = g;
					      		PWB.db.profile.rageFrame.colorMax[3] = b;
					      		PWB.db.profile.rageFrame.colorMax[4] = a;
					      	 	Protwarbar:RefreshConfig() 
					      		end,
				      	get = function(info) return PWB.db.profile.rageFrame.colorMax[1], PWB.db.profile.rageFrame.colorMax[2],
				      								PWB.db.profile.rageFrame.colorMax[3], PWB.db.profile.rageFrame.colorMax[4] 
							end
					},
					desc_bg_head = {
						type = 'header',
						name = L["Bar background"],
						order = 31,
					},
				    barTexture = {
				    	name = L["Texture"],
				    	desc = L["Texture for ragebar"],
				    	type = "select",
				    	values = textures,
				    	order = 32,
				      	set = function(info, v)
				      			PWB.db.profile.rageFrame.texture = media:List("statusbar")[v]
					      	 	Protwarbar:RefreshConfig() 
				      		end,
				      	get = function(info) return GetLSMIndex("statusbar", PWB.db.profile.rageFrame.texture) end
					},
					desc_colour32 = {
						type = 'description',
						name = " ",
						order = 33,
					},						
				    bg = {
				    	name = L["Background color"],
				    	desc = L["Color of bar Background"],
				    	type = "color",
				    	order = 34,
				    	hasAlpha = true,
				      	set = function(info, r, g, b, a) 
					      		PWB.db.profile.rageFrame.background[1] = r;
					      		PWB.db.profile.rageFrame.background[2] = g;
					      		PWB.db.profile.rageFrame.background[3] = b;
					      		PWB.db.profile.rageFrame.background[4] = a;
					      	 	Protwarbar:RefreshConfig() 
					      		end,
				      	get = function(info) return PWB.db.profile.rageFrame.background[1], PWB.db.profile.rageFrame.background[2],
				      								PWB.db.profile.rageFrame.background[3], PWB.db.profile.rageFrame.background[4] 
							end
					},

					desc_bg = {
						type = 'header',
						name = L["Bar text"],
						order = 50,
					},						
				    barFont = {
				    	name = L["Font"],
				    	desc = L["Font for ragebar"],
				    	type = "select",
				    	values = fonts,
				    	order = 51,
				      	set = function(info, v)
				      			PWB.db.profile.rageFrame.font = media:List("font")[v]
					      	 	Protwarbar:RefreshConfig() 
				      		end,
				      	get = function(info) return GetLSMIndex("font", PWB.db.profile.rageFrame.font) end
					},
					desc_52 = {
						type = 'description',
						name = " ",
						order = 52,
					},						
				    fontsize = {
				        order = 53,
				    	name = L["Font Size"],
				    	desc = L["Size of the font used on the ragebar"],
				    	type = "range",
				    	min = 3,
				    	max = 50,
				    	step = 1,
				      	set = function(info,val) PWB.db.profile.rageFrame.fontsize = val Protwarbar:RefreshConfig() end,
				      	get = function(info) return PWB.db.profile.rageFrame.fontsize end
					},					
				},
			},
			group4 = {
				name = L["Icons"],
				type = "group",
				order = 4,
				childGroups = "tree",
				args = {
					icons1 = {
						name = L["General"],
						type = "group",
						order = 4,
						args = {
							desc_pos = {
								type = 'header',
								name = L["Icons"],
								order = 1,
							},
							hideicons = {
							  order = 2,
						      name = L["Icons enabled"],
						      desc = L["Display the helper icons."],
							  type = "toggle",
						      set = function(info,val) PWB.db.profile.IconsEnabled = val Protwarbar:RefreshConfig() end,
						      get = function(info) return PWB.db.profile.IconsEnabled end
						    },						
							desc_310 = {
								type = 'description',
								name = " ",
								order = 10,
							},					
						},
					},
					icon1 = Protwarbar:GetIconOptions(PWB.db.profile.icons[1], 5),
					icon2 = Protwarbar:GetIconOptions(PWB.db.profile.icons[2], 6),
					icon3 = Protwarbar:GetIconOptions(PWB.db.profile.icons[3], 7),
					icon4 = Protwarbar:GetIconOptions(PWB.db.profile.icons[4], 8),
					icon5 = Protwarbar:GetIconOptions(PWB.db.profile.icons[5], 9),
					icon6 = Protwarbar:GetIconOptions(PWB.db.profile.icons[6], 10),
					icon7 = Protwarbar:GetIconOptions(PWB.db.profile.icons[7], 11),
					icon8 = Protwarbar:GetIconOptions(PWB.db.profile.icons[8], 12),
					icon9 = Protwarbar:GetIconOptions(PWB.db.profile.icons[9], 13),
					icon10 = Protwarbar:GetIconOptions(PWB.db.profile.icons[10], 14),
					icon11 = Protwarbar:GetIconOptions(PWB.db.profile.icons[11], 15),
					icon12 = Protwarbar:GetIconOptions(PWB.db.profile.icons[12], 16),
					icon13 = Protwarbar:GetIconOptions(PWB.db.profile.icons[13], 17),
					icon14 = Protwarbar:GetIconOptions(PWB.db.profile.icons[14], 18),					

				},
			},
			group5 = {
				name = L["Information"],
				type = "group",
				order = 5,
				args = {
					enable = {
					  order = 1,
				      name = L["Enable"],
				      desc = L["Enable the information frame"],
					  type = "toggle",
				      set = function(info,val) PWB.db.profile.InformationFrame.enabled = val Protwarbar:RefreshConfig() end,
				      get = function(info) return PWB.db.profile.InformationFrame.enabled end
				    },
					desc_pos = {
						type = 'header',
						name = L["Position"],
						order = 2,
					},
				    x = {
				        order = 4,
				    	name = "X",
				    	desc = "X",
				    	type = "range",
				    	min = 1,
				    	max = 2560,
				    	step = 1,
				      	set = function(info,val) PWB.db.profile.InformationFrame.x = val Protwarbar:RefreshConfig() end,
				      	get = function(info) return PWB.db.profile.InformationFrame.x end
					},
				    you = {
				        order = 5,
				    	name = "Y",
				    	desc = "Y",
				    	type = "range",
				    	min = 1,
				    	max = 2048,
				    	step = 1,
				      	set = function(info,val) PWB.db.profile.InformationFrame.y = val Protwarbar:RefreshConfig() end,
				      	get = function(info) return PWB.db.profile.InformationFrame.y end
					},					
					desc_6 = {
						type = 'description',
						name = " ",
						order = 6,
					},					
				    venwidth = {
				        order = 7,
				    	name = L["Width"],
				    	desc = L["Width of information frame"],
				    	type = "range",
				    	min = 5,
				    	max = 200,
				    	step = 1,
				      	set = function(info,val) PWB.db.profile.InformationFrame.width = val Protwarbar:RefreshConfig() end,
				      	get = function(info) return PWB.db.profile.InformationFrame.width end
					},
				    venheight = {
				        order = 8,
				    	name = L["Height"],
				    	desc = L["Height of information frame"],
				    	type = "range",
				    	min = 5,
				    	max = 200,
				    	step = 1,
				      	set = function(info,val) PWB.db.profile.InformationFrame.height = val Protwarbar:RefreshConfig() end,
				      	get = function(info) return PWB.db.profile.InformationFrame.height end
					},
					desc_ven_head = {
						type = 'header',
						name = L["Information text"],
						order = 10,
					},
				    venFont = {
				    	name = L["Font"],
				    	desc = L["Font for information"],
				    	type = "select",
				    	values = fonts,
				    	order = 11,
				      	set = function(info, v)
				      			PWB.db.profile.InformationFrame.font = media:List("font")[v]
					      	 	Protwarbar:RefreshConfig() 
				      		end,
				      	get = function(info) return GetLSMIndex("font", PWB.db.profile.InformationFrame.font) end
					},
					desc_412 = {
						type = 'description',
						name = " ",
						order = 12,
					},						
				    venfontsize = {
				        order = 13,
				    	name = L["Font Size"],
				    	desc = L["Size of the font used for information"],
				    	type = "range",
				    	min = 3,
				    	max = 50,
				    	step = 1,
				      	set = function(info,val) PWB.db.profile.InformationFrame.fontsize = val Protwarbar:RefreshConfig() end,
				      	get = function(info) return PWB.db.profile.InformationFrame.fontsize end
					},	
					desc_420 = {
						type = 'header',
						name = L["Information elements"],
						order = 20,
					},
					enableven = {
					  order = 21,
				      name = L["Display Vengeance"],
				      desc = L["Display Vengeance"],
					  type = "toggle",
				      set = function(info,val) PWB.db.profile.InformationFrame.vengeance.enabled = val Protwarbar:RefreshConfig() end,
				      get = function(info) return PWB.db.profile.InformationFrame.vengeance.enabled end
				    },
				    enablesb = {
					  order = 22,
				      name = L["Display Shield Barrier"],
				      desc = L["Display Shield Barrier"],
					  type = "toggle",
				      set = function(info,val) PWB.db.profile.InformationFrame.shieldBarrier.enabled = val Protwarbar:RefreshConfig() end,
				      get = function(info) return PWB.db.profile.InformationFrame.shieldBarrier.enabled end
				    },
				},
			},
		    group3 = {
				name = L["Shield bar"],
				type = "group",
				order = 3,
				childGroups = "tree",
				args = {
					barg = {
						name = L["General"],
						type = "group",
						order = 1,
						args = {
							enable = {
						  		order = 1,
					      		name = L["Enable"],
					      		desc = L["Enable the Shield Bar"],
						  		type = "toggle",
					      		set = function(info,val) PWB.db.profile.shieldFrame.enabled = val Protwarbar:RefreshConfig() end,
					      		get = function(info) return PWB.db.profile.shieldFrame.enabled end
						    },				
							desc_pos = {
								type = 'header',
								name = L["Position"],
								order = 2,
							},
						    x = {
						        order = 3,
						    	name = "X",
						    	desc = "X",
						    	type = "range",
						    	min = 1,
						    	max = 2560,
						    	step = 1,
						      	set = function(info,val) PWB.db.profile.shieldFrame.x = val Protwarbar:RefreshConfig() end,
						      	get = function(info) return PWB.db.profile.shieldFrame.x end
							},
						    y = {
						        order = 3,
						    	name = "Y",
						    	desc = "Y",
						    	type = "range",
						    	min = 1,
						    	max = 2048,
						    	step = 1,
						      	set = function(info,val) PWB.db.profile.shieldFrame.y = val Protwarbar:RefreshConfig() end,
						      	get = function(info) return PWB.db.profile.shieldFrame.y end
							},					
							desc_6 = {
								type = 'description',
								name = " ",
								order = 6,
							},
						    width = {
						        order = 7,
						    	name = L["Width"],
						    	desc = L["Width of rage bar"],
						    	type = "range",
						    	min = 1,
						    	max = 750,
						    	step = 1,
						      	set = function(info,val) PWB.db.profile.shieldFrame.width = val Protwarbar:RefreshConfig() end,
						      	get = function(info) return PWB.db.profile.shieldFrame.width end
							},
						    height = {
						        order = 8,
						    	name = L["Height"],
						    	desc = L["Height of bar"],
						    	type = "range",
						    	min = 1,
						    	max = 750,
						    	step = 1,
						      	set = function(info,val) PWB.db.profile.shieldFrame.height = val Protwarbar:RefreshConfig() end,
						      	get = function(info) return PWB.db.profile.shieldFrame.height end
							},
						    orient = {
						        order = 9,
						    	name = L["Orientation"],
						    	desc = L["Orientation"],
						    	type = "select",
								values = function()
									orientations = {
										["HORIZONTAL"] = "Horizontal",
										["VERTICAL"] = "Vertical",
									}
									return orientations
								end,
						      	set = function(info, v)
						      			PWB.db.profile.shieldFrame.orientation = v
							      	 	Protwarbar:RefreshConfig() 
						      		end,
						      	get = function(info) return PWB.db.profile.shieldFrame.orientation end
							},
							desc_bg_head = {
								type = 'header',
								name = L["Bar background"],
								order = 30,
							},
						    barTexture = {
						    	name = L["Texture"],
						    	desc = L["Texture for ragebar"],
						    	type = "select",
						    	values = textures,
						    	order = 31,
						      	set = function(info, v)
						      			PWB.db.profile.shieldFrame.texture = media:List("statusbar")[v]
							      	 	Protwarbar:RefreshConfig() 
						      		end,
						      	get = function(info) return GetLSMIndex("statusbar", PWB.db.profile.shieldFrame.texture) end
							},
						    bg = {
						    	name = L["Background color"],
						    	desc = L["Color of bar Background"],
						    	type = "color",
						    	order = 33,
						    	hasAlpha = true,
						      	set = function(info, r, g, b, a) 
							      		PWB.db.profile.shieldFrame.background[1] = r;
							      		PWB.db.profile.shieldFrame.background[2] = g;
							      		PWB.db.profile.shieldFrame.background[3] = b;
							      		PWB.db.profile.shieldFrame.background[4] = a;
							      	 	Protwarbar:RefreshConfig() 
						      		end,
						      	get = function(info) return PWB.db.profile.shieldFrame.background[1], PWB.db.profile.shieldFrame.background[2],
						      								PWB.db.profile.shieldFrame.background[3], PWB.db.profile.shieldFrame.background[4] 
				      		   	end
							},
							desc_text_bg = {
								type = 'header',
								name = L["Information text"],
								order = 50,
							},
							enable_info = {
						  		order = 51,
					      		name = L["Enable"],
					      		desc = L["Enable"],
						  		type = "toggle",
					      		set = function(info,val) PWB.db.profile.shieldFrame.infoFrame.enabled = val Protwarbar:RefreshConfig() end,
					      		get = function(info) return PWB.db.profile.shieldFrame.infoFrame.enabled end
						    },
							desc_6 = {
								type = 'description',
								name = " ",
								order = 52,
							},
						    font = {
						    	name = L["Font"],
						    	desc = L["Font for ragebar"],
						    	type = "select",
						    	values = fonts,
						    	order = 53,
						      	set = function(info, v)
						      			PWB.db.profile.shieldFrame.infoFrame.font = media:List("font")[v]
							      	 	Protwarbar:RefreshConfig() 
						      		end,
						      	get = function(info) return GetLSMIndex("font", PWB.db.profile.shieldFrame.infoFrame.font) end
							},
							fontsize = {
						        order = 55,
						    	name = L["Font Size"],
						    	desc = L["Size of the font used on the ragebar"],
						    	type = "range",
						    	min = 3,
						    	max = 50,
						    	step = 1,
						      	set = function(info,val) PWB.db.profile.shieldFrame.infoFrame.fontsize = val Protwarbar:RefreshConfig() end,
						      	get = function(info) return PWB.db.profile.shieldFrame.infoFrame.fontsize end
							},							
						},
					},
					bar1 = Protwarbar:GetBarOptions(PWB.db.profile.bars[1], 15),
					bar2 = Protwarbar:GetBarOptions(PWB.db.profile.bars[2], 16),
					bar3 = Protwarbar:GetBarOptions(PWB.db.profile.bars[3], 17),
					bar4 = Protwarbar:GetBarOptions(PWB.db.profile.bars[4], 18),
					bar5 = Protwarbar:GetBarOptions(PWB.db.profile.bars[5], 19),
					bar6 = Protwarbar:GetBarOptions(PWB.db.profile.bars[6], 20),
				},
			},

		},
	}

	return options
end

function GetLSMIndex(t, value)
	local media = LibStub("LibSharedMedia-3.0")

	for k, v in pairs(media:List(t)) do
		if v == value then
			return k
		end
	end
	return nil
end

function Protwarbar:GetIconOptions(icon, index)

	icon_opt = {
		name = icon.name,
		type = "group",
		order = index,
		args = {
			icon_hide = {
			  order = 2,
		      name = L["Icon enabled"],
		      desc = L["Display this the helper icons"],
			  type = "toggle",
		      set = function(info,val) icon.enabled = val Protwarbar:RefreshConfig() end,
		      get = function(info) return icon.enabled end
		    },
			bs_oncd = {
			  order = 3,
		      name = L["Hide on cooldown"],
		      desc = L["Hide on cooldown"],
			  type = "toggle",
		      set = function(info,val) icon.hideOnCD = val Protwarbar:RefreshConfig() end,
		      get = function(info) return icon.hideOnCD end
		    },						
			desc_pos = {
				type = 'header',
				name = L["Position"],
				order = 4,
			},
		    x = {
		        order = 5,
		    	name = "X",
		    	desc = "X",
		    	type = "range",
		    	min = 1,
		    	max = 2560,
		    	step = 1,
		      	set = function(info,val) icon.x = val Protwarbar:RefreshConfig() end,
		      	get = function(info) return icon.x end
			},
		    y = {
		        order = 6,
		    	name = "Y",
		    	desc = "Y",
		    	type = "range",
		    	min = 1,
		    	max = 2048,
		    	step = 1,
		      	set = function(info,val) icon.y = val Protwarbar:RefreshConfig() end,
		      	get = function(info) return icon.y end
			},
		    size = {
		        order = 11,
		    	name = L["Size"],
		    	desc = L["Size of the icons"],
		    	type = "range",
		    	min = 5,
		    	max = 100,
		    	step = 1,
		      	set = function(info,val) icon.size = val Protwarbar:RefreshConfig() end,
		      	get = function(info) return icon.size end
			},							
		},
	}

	return icon_opt
end

function Protwarbar:GetBarOptions(bar, index)
    bar_opt = {
		name = bar.name,
		type = "group",
		order = index,
		args = {
			bar_hide = {
			  order = 1,
		      name = L["Enable"],
		      desc = L["Enable"],
			  type = "toggle",
		      set = function(info,val) bar.enabled = val Protwarbar:RefreshConfig() end,
		      get = function(info) return bar.enabled end
		    },		
			desc_pos = {
				type = 'header',
				name = L["Bar color"],
				order = 2,
			},		
			color = {
		    	name = L["Bar color"],
		    	desc = L["Bar color"],
		    	type = "color",
		    	order = 3,
		    	hasAlpha = true,
		      	set = function(info, r, g, b, a) 
			      		bar.color[1] = r;
			      		bar.color[2] = g;
			      		bar.color[3] = b;
			      		bar.color[4] = a;
			      	 	Protwarbar:RefreshConfig() 
		      		end,
		      	get = function(info) return bar.color[1], bar.color[2],	bar.color[3], bar.color[4] end
			},
      	},
	}

	return bar_opt
end